


#ifndef SRC_GST_GST_ENUM_TYPES_H_
#define SRC_GST_GST_ENUM_TYPES_H_
#include <glib-object.h>
G_BEGIN_DECLS
/* enumerations from "parole-gst.h" */
GType parole_aspect_ratio_get_type (void);
#define GST_ENUM_TYPE_ASPECT_RATIO (parole_aspect_ratio_get_type())
G_END_DECLS

#endif /* SRC_GST_GST_ENUM_TYPES_H_ */



